
Benchmarking with asv
=====================

:epkg:`asv` is a popular framework to run evaluate time
and peak memory for a script. Following functions automates
the create of such a benchmark to compare :epkg:`onnxruntime`
to :epkg:`scikit-learn` for predictions.

.. autosignature:: mlprodict.asv_benchmark.asv_exports.export_asv_json

.. autosignature:: mlprodict.asv_benchmark.create_asv.create_asv_benchmark
